@@ -36,3 +36,9 @@ class InMemoryStorage(StorageIOBase, FullyFeaturedMixin):
 
     def _write_bytes(self, uid: str, item: bytes) -> None:
         self.__storage[uid] = item
+
+    def _delete(self, __uid: str, /, *, missing_ok: bool = False) -> None:
+        if missing_ok:
+            self.__storage.pop(__uid, None)
+        else:
+            self.__storage.pop(__uid)
